@@ -7,6 +7,7 @@ from pyotrs.lib import APIError, HTTPError, ResponseParseError, SessionNotCreate
 from otrs_somconnexio.responses.ticket_creation import OTRSCreationTicketResponse
 from otrs_somconnexio.otrs_models.process_ticket.internet import InternetProcessTicket
 from otrs_somconnexio.otrs_models.process_ticket.mobile import MobileProcessTicket
+from otrs_somconnexio.otrs_models.coverage_ticket import CoverageTicket
 from otrs_somconnexio.otrs_models.service import Service
 
 from otrs_somconnexio.exceptions import TicketNotCreated, ErrorCreatingSession, TicketNotFoundError, \
@@ -108,13 +109,14 @@ class OTRSClient():
         except Exception as error:
             raise OTRSIntegrationUnknownError(error.message)
         if not ticket:
-            raise TicketNotFoundError(error.message)
+            raise TicketNotFoundError(ticket_id)
         return self._process_ticket_response(ticket)
 
     def search_tickets(self, **params):
         tickets = []
 
         ticket_ids = self.client.ticket_search(**params)
+
         for ticket_id in ticket_ids:
             ticket = self.client.ticket_get_by_id(ticket_id, dynamic_fields=True)
             tickets.append(self._process_ticket_response(ticket))
@@ -127,12 +129,13 @@ class OTRSClient():
             "value": "Process-be8cf222949132c9fae1bb74615a5ae4"
         }
 
-        return self.search_tickets(
+        tickets = self.search_tickets(
             dynamic_fields=[
                 DynamicField(df_process_id["name"], search_patterns=[df_process_id["value"]]),
                 DynamicField("correuElectronic", search_patterns=[email])
             ]
         )
+        return [CoverageTicket(t) for t in tickets]
 
     def update_ticket(self, ticket_id, article):
         self.client.ticket_update(ticket_id, article)
