@@ -1,5 +1,5 @@
 # coding: utf-8
-from abstract_article import AbstractArticle
+from otrs_somconnexio.otrs_models.abstract_article import AbstractArticle
 
 
 class InternetArticle(AbstractArticle):
