@@ -1,31 +1,12 @@
 # coding: utf-8
-import logging
-
 from pyotrs.lib import DynamicField
-
+from otrs_somconnexio.otrs_models.telecom_company import TelecomCompany
 from otrs_somconnexio.ticket_exceptions import CustomerMailMissing,\
     CustomerVatNumberMissing
 
 
-log = logging.getLogger('otrs_somconnexio')
-
-
 class InternetDynamicFields():
 
-    # This dict is to map the telecom companies from Tryton to OTRS.
-    # The key is the name in Tryton and the value is the name in OTRS.
-    telecom_companies_mapping = {
-        'Jazztel': 'Jazztel',
-        'MasMovil': 'MasMovil',
-        'Movistar': 'Movistar',
-        'Aire / Nubip': 'Nubip',
-        'Orange': 'Orange',
-        'Parlem': 'Parlem',
-        'PepePhone': 'PepePhone',
-        'Vodafone': 'Vodafone',
-        'Yoigo': 'Yoigo'
-    }
-
     def __init__(self, econtract, otrs_process_id, otrs_activity_id):
         self.eticom_contract = econtract
         self.otrs_process_id = otrs_process_id
@@ -127,12 +108,10 @@ class InternetDynamicFields():
         return DynamicField(name="serveiPrevi", value=value)
 
     def _df_previous_provider(self):
-        if not self.eticom_contract.internet_telecom_company:
-            return DynamicField(name="proveidorPrevi", value='None')
-        key = self.eticom_contract.internet_telecom_company.name
         return DynamicField(
             name="proveidorPrevi",
-            value=self.telecom_companies_mapping.get(key, 'Other'))
+            value=str(TelecomCompany('internet', self.eticom_contract.internet_telecom_company))
+        )
 
     def _df_landline_number(self):
         if self.eticom_contract.internet_phone_now:
