@@ -23,7 +23,7 @@ class MobileDynamicFields():
         self.otrs_activity_id = otrs_activity_id
 
     def all(self):
-        return [
+        dynamic_fields = [
             self._process_id(),
             self._activity_id(),
             self._first_name(),
@@ -40,6 +40,7 @@ class MobileDynamicFields():
             self._phone(),
             self._df_previous_provider(),
         ]
+        return [field for field in dynamic_fields if field is not None]
 
     def _process_id(self):
         return DynamicField("ProcessManagementProcessID", self.otrs_process_id)
