@@ -1,5 +1,6 @@
 import requests
 import os
+import json
 
 
 class UserManagementClient:
@@ -19,7 +20,7 @@ class UserManagementClient:
 
     @classmethod
     def set_preference(cls, key, user_id, lang):
-        body = {
+        payload = {
             "UserLogin": cls._user(),
             "Password": cls._password(),
             "Object": "Kernel::System::CustomerUser",
@@ -30,5 +31,6 @@ class UserManagementClient:
                 "UserID": user_id
             }
         }
+        json_payload = json.dumps(payload)
         url = '{}{}'.format(cls._url(), cls.WEBSERVICES_PATH)
-        requests.post(url, data=body)
+        requests.post(url, data=json_payload)
