@@ -1,5 +1,6 @@
 import os
 import unittest
+import json
 from mock import patch
 
 from otrs_somconnexio.otrs_models.customer_user import CustomerUser
@@ -36,4 +37,4 @@ class ChangeCustomerUserIntegrationTestCase(unittest.TestCase):
 
         CustomerUser(user_id).change_language(lang)
 
-        requests_mock.post.assert_called_once_with(expected_url, data=expected_body)
+        requests_mock.post.assert_called_once_with(expected_url, data=json.dumps(expected_body))
