@@ -7,7 +7,7 @@ from otrs_somconnexio.otrs_models.mobile_article import MobileArticle
 
 class MobileArticleTestCase(unittest.TestCase):
 
-    @patch('otrs_somconnexio.otrs_models.mobile_article.Article')
+    @patch('otrs_somconnexio.otrs_models.abstract_article.Article')
     def test_call(self, MockArticle):
         service_type = 'mobile'
         eticom_contract = Mock(spec=['id'])
@@ -20,4 +20,4 @@ class MobileArticleTestCase(unittest.TestCase):
         }
 
         MobileArticle(service_type, eticom_contract).call()
-        MockArticle.assert_called_with(expected_article_arguments)
+        MockArticle.assert_called_once_with(expected_article_arguments)
