@@ -1,6 +1,7 @@
 # coding: utf-8
 import os
 import unittest
+import json
 from mock import patch
 
 from otrs_somconnexio.user_management_client.client import UserManagementClient
@@ -38,4 +39,4 @@ class UserManagementClientTestCase(unittest.TestCase):
 
         UserManagementClient().set_preference(preference_key, user_id, lang)
 
-        requests_mock.post.assert_called_once_with(expected_url, data=expected_body)
+        requests_mock.post.assert_called_once_with(expected_url, data=json.dumps(expected_body))
